.. DjVue documentation master file, created by
   sphinx-quickstart on Mon Sep 28 18:19:34 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

####################################
Welcome to DjVue's documentation!
####################################

Overview
========

.. note::

   This guide assumes intermediate knowledge of Django and DjangoRestFramework.
..

**DjVue** (*deʒavy*) is a front/back-end application which allow a simple and fast data interaction through RESTful API
and standard HTTP communication using modern frameworks with an user friendly interface.
DjVue will automatically build the tables reflecting the database using bootstrap design.
DjVue also saves you the repetitive code writing for standard operations on the database such creations, updates and
deletions and leave you the concern of writing just the serializers.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   sections/Installation.rst
   sections/Backend.rst
   sections/Frontend.rst
   sections/CommonRecipes.rst
   sections/DjVueFields.rst
..


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`